@@ -17,7 +17,8 @@ __file_type__ = '.py'
 
 
 def get_attribute(file_path: str, attribute_name: str) -> Any:
-    """Get a module's attribute, by file path and attribute name.
+    """
+    Get a module's attribute, by file path and attribute name.
 
     :param file_path: the absolute path/location of the file.
     :param attribute_name: the attribute you want to extract from the file/module/class
